@@ -1,6 +1,7 @@
 from .jwt_manager import JWTManager
 from .view_decorators import (
-    jwt_required, fresh_jwt_required, jwt_refresh_token_required
+    jwt_required, fresh_jwt_required, jwt_refresh_token_required,
+    jwt_optional
 )
 from .utils import (
     create_refresh_token, create_access_token, get_jwt_identity,
